from . import RomanNumeral

Ⅰ = RomanNumeral("I")
Ⅱ = RomanNumeral("II")
Ⅲ = RomanNumeral("III")
Ⅳ = RomanNumeral("IV")
Ⅴ = RomanNumeral("V")
Ⅵ = RomanNumeral("VI")
Ⅶ = RomanNumeral("VII")
Ⅷ = RomanNumeral("VIII")
Ⅸ = RomanNumeral("IX")
Ⅹ = RomanNumeral("X")
Ⅺ = RomanNumeral("XI")
Ⅻ = RomanNumeral("XII")
Ⅼ = RomanNumeral("L")
Ⅿ = RomanNumeral("M")
