#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['SPQR']

package_data = \
{'': ['*']}

setup(name='SPQR',
      version='0.0.6',
      description='S.P.Q.R',
      author='Matthias Bussonnier',
      author_email='bussonniermatthias@gmail.com',
      url='https://github.com/Carreau/SPQR',
      packages=packages,
      package_data=package_data,
      python_requires='>3',
     )
